@@ -1,3 +1,4 @@
+-- | Ingredient for listing test names
 {-# LANGUAGE GeneralizedNewtypeDeriving, DeriveDataTypeable #-}
 module Test.Tasty.Ingredients.ListTests
   ( ListTests(..)
@@ -5,10 +6,8 @@ module Test.Tasty.Ingredients.ListTests
   , listingTests
   ) where
 
-import Options.Applicative
 import Data.Typeable
 import Data.Proxy
-import Data.Tagged
 
 import Test.Tasty.Core
 import Test.Tasty.Options
@@ -23,13 +22,7 @@ instance IsOption ListTests where
   parseValue = fmap ListTests . safeRead
   optionName = return "list-tests"
   optionHelp = return "Do not run the tests; just print their names"
-  optionCLParser =
-    fmap ListTests $
-    switch
-      (  short 'l'
-      <> long (untag (optionName :: Tagged ListTests String))
-      <> help (untag (optionHelp :: Tagged ListTests String))
-      )
+  optionCLParser = flagCLParser (Just 'l') (ListTests True)
 
 -- | Obtain the list of all tests in the suite
 testsNames :: OptionSet -> TestTree -> [TestName]
