@@ -9,11 +9,13 @@ module Test.Tasty.Options.Core
   )
   where
 
+import Control.Monad (mfilter)
 import Data.Typeable
 import Data.Proxy
 import Data.Tagged
 import Data.Fixed
 import Options.Applicative
+import GHC.Conc
 
 import Test.Tasty.Options
 import Test.Tasty.Patterns
@@ -28,8 +30,8 @@ import Test.Tasty.Patterns
 newtype NumThreads = NumThreads { getNumThreads :: Int }
   deriving (Eq, Ord, Num, Typeable)
 instance IsOption NumThreads where
-  defaultValue = 1
-  parseValue = fmap NumThreads . safeRead
+  defaultValue = NumThreads numCapabilities
+  parseValue = mfilter onlyPositive . fmap NumThreads . safeRead
   optionName = return "num-threads"
   optionHelp = return "Number of threads to use for tests execution"
   optionCLParser =
@@ -43,6 +45,10 @@ instance IsOption NumThreads where
       parse = str >>=
         maybe (readerError $ "Could not parse " ++ name) pure <$> parseValue
 
+-- | Filtering function to prevent non-positive number of threads
+onlyPositive :: NumThreads -> Bool
+onlyPositive (NumThreads x) = x > 0
+
 -- | Timeout to be applied to individual tests
 data Timeout
   = Timeout Integer String
